@@ -5,7 +5,7 @@
  * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
  * Copyright (C) 2000, 2001 Chema Celorio, Paolo Maggi
  * Copyright (C) 2002-2005 Paolo Maggi
- * Copyright (C) 2014 Sébastien Wilmet
+ * Copyright (C) 2014, 2020 Sébastien Wilmet
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,16 +32,24 @@ G_BEGIN_DECLS
 #define GEDIT_METADATA_ATTRIBUTE_ENCODING "gedit-encoding"
 #define GEDIT_METADATA_ATTRIBUTE_LANGUAGE "gedit-language"
 
-glong		 _gedit_document_get_seconds_since_last_save_or_load	(GeditDocument       *doc);
+G_GNUC_INTERNAL
+glong		_gedit_document_get_seconds_since_last_save_or_load	(GeditDocument *doc);
 
-gboolean	 _gedit_document_needs_saving				(GeditDocument       *doc);
+G_GNUC_INTERNAL
+gboolean	_gedit_document_needs_saving				(GeditDocument *doc);
 
-gboolean	 _gedit_document_get_empty_search			(GeditDocument       *doc);
+G_GNUC_INTERNAL
+gboolean	_gedit_document_get_empty_search			(GeditDocument *doc);
 
-void		 _gedit_document_set_create				(GeditDocument       *doc,
-									 gboolean             create);
+G_GNUC_INTERNAL
+void		_gedit_document_set_create				(GeditDocument *doc,
+									 gboolean       create);
 
-gboolean	 _gedit_document_get_create				(GeditDocument       *doc);
+G_GNUC_INTERNAL
+gboolean	_gedit_document_get_create				(GeditDocument *doc);
+
+G_GNUC_INTERNAL
+gchar *		_gedit_document_get_uri_for_display			(GeditDocument *doc);
 
 G_END_DECLS
 
