@@ -5,7 +5,7 @@
  * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
  * Copyright (C) 2000, 2001 Chema Celorio, Paolo Maggi
  * Copyright (C) 2002-2005 Paolo Maggi
- * Copyright (C) 2014-2015 Sébastien Wilmet
+ * Copyright (C) 2014-2020 Sébastien Wilmet
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,14 +22,10 @@
  */
 
 #include "config.h"
-
 #include "gedit-document.h"
 #include "gedit-document-private.h"
-
 #include <string.h>
 #include <glib/gi18n.h>
-#include <tepl/tepl.h>
-
 #include "gedit-settings.h"
 #include "gedit-debug.h"
 #include "gedit-utils.h"
@@ -49,8 +45,6 @@ typedef struct
 
 	TeplMetadata *metadata;
 
-	gint 	     untitled_number;
-
 	gchar	    *content_type;
 
 	GDateTime   *time_of_last_save_or_load;
@@ -60,8 +54,6 @@ typedef struct
 	 */
 	GtkSourceSearchContext *search_context;
 
-	guint user_action;
-
 	guint language_set_by_user : 1;
 
 	/* The search is empty if there is no search context, or if the
@@ -79,7 +71,6 @@ typedef struct
 enum
 {
 	PROP_0,
-	PROP_SHORTNAME,
 	PROP_CONTENT_TYPE,
 	PROP_MIME_TYPE,
 	PROP_EMPTY_SEARCH,
@@ -90,7 +81,6 @@ static GParamSpec *properties[LAST_PROP];
 
 enum
 {
-	CURSOR_MOVED,
 	LOAD,
 	LOADED,
 	SAVE,
@@ -100,9 +90,7 @@ enum
 
 static guint document_signals[LAST_SIGNAL];
 
-static GHashTable *allocated_untitled_numbers = NULL;
-
-G_DEFINE_TYPE_WITH_PRIVATE (GeditDocument, gedit_document, GTK_SOURCE_TYPE_BUFFER)
+G_DEFINE_TYPE_WITH_PRIVATE (GeditDocument, gedit_document, TEPL_TYPE_BUFFER)
 
 static void
 load_metadata_from_metadata_manager (GeditDocument *doc)
@@ -138,39 +126,6 @@ save_metadata_into_metadata_manager (GeditDocument *doc)
 	}
 }
 
-static gint
-get_untitled_number (void)
-{
-	gint i = 1;
-
-	if (allocated_untitled_numbers == NULL)
-		allocated_untitled_numbers = g_hash_table_new (NULL, NULL);
-
-	g_return_val_if_fail (allocated_untitled_numbers != NULL, -1);
-
-	while (TRUE)
-	{
-		if (g_hash_table_lookup (allocated_untitled_numbers, GINT_TO_POINTER (i)) == NULL)
-		{
-			g_hash_table_insert (allocated_untitled_numbers,
-					     GINT_TO_POINTER (i),
-					     GINT_TO_POINTER (i));
-
-			return i;
-		}
-
-		++i;
-	}
-}
-
-static void
-release_untitled_number (gint n)
-{
-	g_return_if_fail (allocated_untitled_numbers != NULL);
-
-	g_hash_table_remove (allocated_untitled_numbers, GINT_TO_POINTER (n));
-}
-
 static void
 update_time_of_last_save_or_load (GeditDocument *doc)
 {
@@ -257,17 +212,10 @@ gedit_document_dispose (GObject *object)
 static void
 gedit_document_finalize (GObject *object)
 {
-	GeditDocumentPrivate *priv;
+	GeditDocumentPrivate *priv = gedit_document_get_instance_private (GEDIT_DOCUMENT (object));
 
 	gedit_debug (DEBUG_DOCUMENT);
 
-	priv = gedit_document_get_instance_private (GEDIT_DOCUMENT (object));
-
-	if (priv->untitled_number > 0)
-	{
-		release_untitled_number (priv->untitled_number);
-	}
-
 	g_free (priv->content_type);
 
 	if (priv->time_of_last_save_or_load != NULL)
@@ -291,10 +239,6 @@ gedit_document_get_property (GObject    *object,
 
 	switch (prop_id)
 	{
-		case PROP_SHORTNAME:
-			g_value_take_string (value, gedit_document_get_short_name_for_display (doc));
-			break;
-
 		case PROP_CONTENT_TYPE:
 			g_value_take_string (value, gedit_document_get_content_type (doc));
 			break;
@@ -333,65 +277,6 @@ gedit_document_set_property (GObject      *object,
 	}
 }
 
-static void
-gedit_document_begin_user_action (GtkTextBuffer *buffer)
-{
-	GeditDocumentPrivate *priv;
-
-	priv = gedit_document_get_instance_private (GEDIT_DOCUMENT (buffer));
-
-	++priv->user_action;
-
-	if (GTK_TEXT_BUFFER_CLASS (gedit_document_parent_class)->begin_user_action != NULL)
-	{
-		GTK_TEXT_BUFFER_CLASS (gedit_document_parent_class)->begin_user_action (buffer);
-	}
-}
-
-static void
-gedit_document_end_user_action (GtkTextBuffer *buffer)
-{
-	GeditDocumentPrivate *priv;
-
-	priv = gedit_document_get_instance_private (GEDIT_DOCUMENT (buffer));
-
-	--priv->user_action;
-
-	if (GTK_TEXT_BUFFER_CLASS (gedit_document_parent_class)->end_user_action != NULL)
-	{
-		GTK_TEXT_BUFFER_CLASS (gedit_document_parent_class)->end_user_action (buffer);
-	}
-}
-
-static void
-gedit_document_mark_set (GtkTextBuffer     *buffer,
-                         const GtkTextIter *iter,
-                         GtkTextMark       *mark)
-{
-	GeditDocument *doc = GEDIT_DOCUMENT (buffer);
-	GeditDocumentPrivate *priv;
-
-	priv = gedit_document_get_instance_private (doc);
-
-	if (GTK_TEXT_BUFFER_CLASS (gedit_document_parent_class)->mark_set != NULL)
-	{
-		GTK_TEXT_BUFFER_CLASS (gedit_document_parent_class)->mark_set (buffer, iter, mark);
-	}
-
-	if (mark == gtk_text_buffer_get_insert (buffer) && (priv->user_action == 0))
-	{
-		g_signal_emit (doc, document_signals[CURSOR_MOVED], 0);
-	}
-}
-
-static void
-gedit_document_changed (GtkTextBuffer *buffer)
-{
-	g_signal_emit (GEDIT_DOCUMENT (buffer), document_signals[CURSOR_MOVED], 0);
-
-	GTK_TEXT_BUFFER_CLASS (gedit_document_parent_class)->changed (buffer);
-}
-
 static void
 gedit_document_constructed (GObject *object)
 {
@@ -414,7 +299,6 @@ static void
 gedit_document_class_init (GeditDocumentClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	GtkTextBufferClass *buf_class = GTK_TEXT_BUFFER_CLASS (klass);
 
 	object_class->dispose = gedit_document_dispose;
 	object_class->finalize = gedit_document_finalize;
@@ -422,26 +306,9 @@ gedit_document_class_init (GeditDocumentClass *klass)
 	object_class->set_property = gedit_document_set_property;
 	object_class->constructed = gedit_document_constructed;
 
-	buf_class->begin_user_action = gedit_document_begin_user_action;
-	buf_class->end_user_action = gedit_document_end_user_action;
-	buf_class->mark_set = gedit_document_mark_set;
-	buf_class->changed = gedit_document_changed;
-
 	klass->loaded = gedit_document_loaded_real;
 	klass->saved = gedit_document_saved_real;
 
-	/**
-	 * GeditDocument:shortname:
-	 *
-	 * The document's short name.
-	 */
-	properties[PROP_SHORTNAME] =
-		g_param_spec_string ("shortname",
-		                     "Short Name",
-		                     "The document's short name",
-		                     NULL,
-		                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
-
 	/**
 	 * GeditDocument:content-type:
 	 *
@@ -483,23 +350,6 @@ gedit_document_class_init (GeditDocumentClass *klass)
 
 	g_object_class_install_properties (object_class, LAST_PROP, properties);
 
-	/* This signal is used to update the cursor position in the statusbar,
-	 * it's emitted either when the insert mark is moved explicitely or
-	 * when the buffer changes (insert/delete).
-	 * FIXME When the replace_all was implemented in gedit, this signal was
-	 * not emitted during the replace_all to improve performance. Now the
-	 * replace_all is implemented in GtkSourceView, so the signal is
-	 * emitted.
-	 */
-	document_signals[CURSOR_MOVED] =
-		g_signal_new ("cursor-moved",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GeditDocumentClass, cursor_moved),
-			      NULL, NULL, NULL,
-			      G_TYPE_NONE,
-			      0);
-
 	/**
 	 * GeditDocument::load:
 	 * @document: the #GeditDocument.
@@ -782,39 +632,20 @@ on_location_changed (GtkSourceFile *file,
 		     GParamSpec    *pspec,
 		     GeditDocument *doc)
 {
-	GeditDocumentPrivate *priv;
-	GFile *location;
-
 	gedit_debug (DEBUG_DOCUMENT);
-
-	priv = gedit_document_get_instance_private (doc);
-
 	load_metadata_from_metadata_manager (doc);
-
-	location = gtk_source_file_get_location (file);
-
-	if (location != NULL && priv->untitled_number > 0)
-	{
-		release_untitled_number (priv->untitled_number);
-		priv->untitled_number = 0;
-	}
-
-	g_object_notify_by_pspec (G_OBJECT (doc), properties[PROP_SHORTNAME]);
 }
 
 static void
 gedit_document_init (GeditDocument *doc)
 {
 	GeditDocumentPrivate *priv = gedit_document_get_instance_private (doc);
+	TeplFile *tepl_file;
 	GeditSettings *settings;
 	GSettings *editor_settings;
 
 	gedit_debug (DEBUG_DOCUMENT);
 
-	settings = _gedit_settings_get_singleton ();
-	editor_settings = _gedit_settings_peek_editor_settings (settings);
-
-	priv->untitled_number = get_untitled_number ();
 	priv->content_type = get_default_content_type ();
 	priv->language_set_by_user = FALSE;
 	priv->empty_search = TRUE;
@@ -822,6 +653,12 @@ gedit_document_init (GeditDocument *doc)
 	update_time_of_last_save_or_load (doc);
 
 	priv->file = gtk_source_file_new ();
+	tepl_file = tepl_buffer_get_file (TEPL_BUFFER (doc));
+
+	g_object_bind_property (priv->file, "location",
+				tepl_file, "location",
+				G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
+
 	priv->metadata = tepl_metadata_new ();
 
 	g_signal_connect_object (priv->file,
@@ -830,6 +667,9 @@ gedit_document_init (GeditDocument *doc)
 				 doc,
 				 0);
 
+	settings = _gedit_settings_get_singleton ();
+	editor_settings = _gedit_settings_peek_editor_settings (settings);
+
 	g_settings_bind (editor_settings, GEDIT_SETTINGS_MAX_UNDO_ACTIONS,
 	                 doc, "max-undo-levels",
 	                 G_SETTINGS_BIND_GET | G_SETTINGS_BIND_NO_SENSITIVITY);
@@ -970,28 +810,21 @@ set_content_type (GeditDocument *doc,
 	}
 }
 
-/**
- * gedit_document_get_uri_for_display:
- * @doc: a #GeditDocument.
- *
- * Note: this never returns %NULL.
- **/
+/* Note: this never returns %NULL. */
 gchar *
-gedit_document_get_uri_for_display (GeditDocument *doc)
+_gedit_document_get_uri_for_display (GeditDocument *doc)
 {
-	GeditDocumentPrivate *priv;
+	TeplFile *file;
 	GFile *location;
 
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), g_strdup (""));
 
-	priv = gedit_document_get_instance_private (doc);
-
-	location = gtk_source_file_get_location (priv->file);
+	file = tepl_buffer_get_file (TEPL_BUFFER (doc));
+	location = tepl_file_get_location (file);
 
 	if (location == NULL)
 	{
-		return g_strdup_printf (_("Untitled Document %d"),
-					priv->untitled_number);
+		return tepl_file_get_short_name (file);
 	}
 	else
 	{
@@ -1008,24 +841,12 @@ gedit_document_get_uri_for_display (GeditDocument *doc)
 gchar *
 gedit_document_get_short_name_for_display (GeditDocument *doc)
 {
-	GeditDocumentPrivate *priv;
-	GFile *location;
+	TeplFile *file;
 
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), g_strdup (""));
 
-	priv = gedit_document_get_instance_private (doc);
-
-	location = gtk_source_file_get_location (priv->file);
-
-	if (location == NULL)
-	{
-		return g_strdup_printf (_("Untitled Document %d"),
-					priv->untitled_number);
-	}
-	else
-	{
-		return gedit_utils_basename_for_display (location);
-	}
+	file = tepl_buffer_get_file (TEPL_BUFFER (doc));
+	return tepl_file_get_short_name (file);
 }
 
 gchar *
@@ -1211,31 +1032,15 @@ gedit_document_saved_real (GeditDocument *doc)
 				 doc);
 }
 
-gboolean
-gedit_document_is_untouched (GeditDocument *doc)
-{
-	GeditDocumentPrivate *priv;
-	GFile *location;
-
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), TRUE);
-
-	priv = gedit_document_get_instance_private (doc);
-
-	location = gtk_source_file_get_location (priv->file);
-
-	return location == NULL && !gtk_text_buffer_get_modified (GTK_TEXT_BUFFER (doc));
-}
-
 gboolean
 gedit_document_is_untitled (GeditDocument *doc)
 {
-	GeditDocumentPrivate *priv;
+	TeplFile *file;
 
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), TRUE);
 
-	priv = gedit_document_get_instance_private (doc);
-
-	return gtk_source_file_get_location (priv->file) == NULL;
+	file = tepl_buffer_get_file (TEPL_BUFFER (doc));
+	return tepl_file_get_location (file) == NULL;
 }
 
 /*
@@ -1267,66 +1072,6 @@ _gedit_document_needs_saving (GeditDocument *doc)
 	return (externally_modified || deleted) && !priv->create;
 }
 
-/**
- * gedit_document_goto_line:
- * @doc: a #GeditDocument.
- * @line: the line number.
- *
- * Returns: if @line is bigger than the lines of the document, the cursor is moved
- * to the last line and %FALSE is returned.
- * Deprecated: 3.38: Use tepl_view_goto_line() instead.
- */
-gboolean
-gedit_document_goto_line (GeditDocument *doc,
-			  gint           line)
-{
-	GtkTextIter iter;
-
-	gedit_debug (DEBUG_DOCUMENT);
-
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), FALSE);
-	g_return_val_if_fail (line >= -1, FALSE);
-
-	gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (doc),
-					  &iter,
-					  line);
-
-	gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (doc), &iter);
-
-	return gtk_text_iter_get_line (&iter) == line;
-}
-
-/**
- * gedit_document_goto_line_offset:
- * @doc: a #GeditDocument.
- * @line: the line.
- * @line_offset: the line offset.
- *
- * Returns: the return value.
- * Deprecated: 3.38: Use tepl_view_goto_line_offset() instead.
- */
-gboolean
-gedit_document_goto_line_offset (GeditDocument *doc,
-				 gint           line,
-				 gint           line_offset)
-{
-	GtkTextIter iter;
-
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), FALSE);
-	g_return_val_if_fail (line >= -1, FALSE);
-	g_return_val_if_fail (line_offset >= -1, FALSE);
-
-	gtk_text_buffer_get_iter_at_line_offset (GTK_TEXT_BUFFER (doc),
-						 &iter,
-						 line,
-						 line_offset);
-
-	gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (doc), &iter);
-
-	return (gtk_text_iter_get_line (&iter) == line &&
-		gtk_text_iter_get_line_offset (&iter) == line_offset);
-}
-
 /**
  * gedit_document_set_language:
  * @doc:
