@@ -26,6 +26,7 @@
 #include <tepl/tepl.h>
 
 #include "gedit-debug.h"
+#include "gedit-document-private.h"
 #include "gedit-print-preview.h"
 #include "gedit-utils.h"
 #include "gedit-dirs.h"
@@ -533,7 +534,7 @@ create_compositor (GeditPrintJob *job)
 		gchar *name_to_display;
 		gchar *left;
 
-		doc_name = gedit_document_get_uri_for_display (GEDIT_DOCUMENT (buf));
+		doc_name = _gedit_document_get_uri_for_display (GEDIT_DOCUMENT (buf));
 		name_to_display = tepl_utils_str_middle_truncate (doc_name, 60);
 
 		left = g_strdup_printf (_("File: %s"), name_to_display);
