@@ -1,5 +1,4 @@
 /*
- * gedit-status-menu-button.c
  * This file is part of gedit
  *
  * Copyright (C) 2008 - Jesse van den Kieboom
@@ -24,25 +23,16 @@ struct _GeditStatusMenuButton
 {
 	GtkMenuButton parent_instance;
 
-	GtkWidget *label;
+	GtkLabel *label;
 };
 
-typedef struct
-{
-	GtkCssProvider *css;
-} GeditStatusMenuButtonClassPrivate;
-
 enum
 {
 	PROP_0,
-	PROP_LABEL,
-	LAST_PROP
+	PROP_LABEL
 };
 
-G_DEFINE_TYPE_WITH_CODE (GeditStatusMenuButton,
-			 gedit_status_menu_button,
-			 GTK_TYPE_MENU_BUTTON,
-			 g_type_add_class_private (g_define_type_id, sizeof (GeditStatusMenuButtonClassPrivate)))
+G_DEFINE_TYPE (GeditStatusMenuButton, gedit_status_menu_button, GTK_TYPE_MENU_BUTTON)
 
 static void
 gedit_status_menu_button_get_property (GObject    *object,
@@ -50,13 +40,14 @@ gedit_status_menu_button_get_property (GObject    *object,
 				       GValue     *value,
 				       GParamSpec *pspec)
 {
-	GeditStatusMenuButton *obj = GEDIT_STATUS_MENU_BUTTON (object);
+	GeditStatusMenuButton *button = GEDIT_STATUS_MENU_BUTTON (object);
 
 	switch (prop_id)
 	{
 		case PROP_LABEL:
-			g_value_set_string (value, gedit_status_menu_button_get_label (obj));
+			g_value_set_string (value, gedit_status_menu_button_get_label (button));
 			break;
+
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -69,13 +60,14 @@ gedit_status_menu_button_set_property (GObject      *object,
 				       const GValue *value,
 				       GParamSpec   *pspec)
 {
-	GeditStatusMenuButton *obj = GEDIT_STATUS_MENU_BUTTON (object);
+	GeditStatusMenuButton *button = GEDIT_STATUS_MENU_BUTTON (object);
 
 	switch (prop_id)
 	{
 		case PROP_LABEL:
-			gedit_status_menu_button_set_label (obj, g_value_get_string (value));
+			gedit_status_menu_button_set_label (button, g_value_get_string (value));
 			break;
+
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -85,16 +77,8 @@ gedit_status_menu_button_set_property (GObject      *object,
 static void
 gedit_status_menu_button_class_init (GeditStatusMenuButtonClass *klass)
 {
-	static const gchar style[] =
-		"* {\n"
-		  "padding: 1px 8px 2px 4px;\n"
-		  "border: 0;\n"
-		  "outline-width: 0;\n"
-		"}";
-
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
-	GeditStatusMenuButtonClassPrivate *class_priv;
 
 	object_class->get_property = gedit_status_menu_button_get_property;
 	object_class->set_property = gedit_status_menu_button_set_property;
@@ -105,43 +89,42 @@ gedit_status_menu_button_class_init (GeditStatusMenuButtonClass *klass)
 	gtk_widget_class_set_template_from_resource (widget_class,
 	                                             "/org/gnome/gedit/ui/gedit-status-menu-button.ui");
 	gtk_widget_class_bind_template_child_internal (widget_class, GeditStatusMenuButton, label);
-
-	/* Store the CSS provider in the class private data so it is shared among all instances */
-	class_priv = G_TYPE_CLASS_GET_PRIVATE (klass, GEDIT_TYPE_STATUS_MENU_BUTTON, GeditStatusMenuButtonClassPrivate);
-	class_priv->css = gtk_css_provider_new ();
-	gtk_css_provider_load_from_data (class_priv->css, style, -1, NULL);
 }
 
 static void
-gedit_status_menu_button_init (GeditStatusMenuButton *self)
+gedit_status_menu_button_init (GeditStatusMenuButton *button)
 {
+	GtkCssProvider *css_provider;
 	GtkStyleContext *context;
-	GeditStatusMenuButtonClassPrivate *class_priv;
+	const gchar *css_style =
+		"* {\n"
+		"  padding: 1px 8px 2px 4px;\n"
+		"  border: 0;\n"
+		"  outline-width: 0;\n"
+		"}\n";
 
-	gtk_widget_init_template (GTK_WIDGET (self));
+	gtk_widget_init_template (GTK_WIDGET (button));
 
-	/* make it as small as possible */
-	context = gtk_widget_get_style_context (GTK_WIDGET (self));
-	class_priv = G_TYPE_CLASS_GET_PRIVATE (G_TYPE_INSTANCE_GET_CLASS (self, GEDIT_TYPE_STATUS_MENU_BUTTON, GeditStatusMenuButtonClass),
-	                                       GEDIT_TYPE_STATUS_MENU_BUTTON,
-	                                       GeditStatusMenuButtonClassPrivate);
+	/* Make it as small as possible. */
+	css_provider = gtk_css_provider_new ();
+	gtk_css_provider_load_from_data (css_provider, css_style, -1, NULL);
+
+	context = gtk_widget_get_style_context (GTK_WIDGET (button));
 	gtk_style_context_add_provider (context,
-	                                GTK_STYLE_PROVIDER (class_priv->css),
-	                                GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+					GTK_STYLE_PROVIDER (css_provider),
+					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+	g_object_unref (css_provider);
 }
 
-/**
- * gedit_status_menu_button_new:
- * @label: (allow-none):
- */
 GtkWidget *
 gedit_status_menu_button_new (void)
 {
 	return g_object_new (GEDIT_TYPE_STATUS_MENU_BUTTON, NULL);
 }
 
-/* we cannot rely on gtk_button_set_label since it manually replaces
- * the internal child instead of just setting the property :( */
+/* We cannot rely on gtk_button_set_label() since it manually replaces the
+ * internal child instead of just setting the property :(
+ */
 
 void
 gedit_status_menu_button_set_label (GeditStatusMenuButton *button,
@@ -149,7 +132,7 @@ gedit_status_menu_button_set_label (GeditStatusMenuButton *button,
 {
 	g_return_if_fail (GEDIT_IS_STATUS_MENU_BUTTON (button));
 
-	gtk_label_set_markup (GTK_LABEL (button->label), label);
+	gtk_label_set_markup (button->label, label);
 }
 
 const gchar *
@@ -157,7 +140,7 @@ gedit_status_menu_button_get_label (GeditStatusMenuButton *button)
 {
 	g_return_val_if_fail (GEDIT_IS_STATUS_MENU_BUTTON (button), NULL);
 
-	return gtk_label_get_label (GTK_LABEL (button->label));
+	return gtk_label_get_label (button->label);
 }
 
 /* ex:set ts=8 noet: */
