@@ -1,5 +1,4 @@
 /*
- * gedit-view.c
  * This file is part of gedit
  *
  * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
@@ -21,106 +20,93 @@
  */
 
 #include "gedit-view.h"
-
 #include <libpeas/peas-extension-set.h>
-#include <glib/gi18n.h>
-
 #include "gedit-view-activatable.h"
 #include "gedit-plugins-engine.h"
 #include "gedit-debug.h"
-#include "gedit-pango.h"
 #include "gedit-utils.h"
 #include "gedit-settings.h"
 
+struct _GeditViewPrivate
+{
+	PeasExtensionSet *extensions;
+
+	gchar *direct_save_uri;
+
+	TeplSignalGroup *file_signal_group;
+};
+
 enum
 {
 	TARGET_URI_LIST = 100,
 	TARGET_XDNDDIRECTSAVE
 };
 
-struct _GeditViewPrivate
+enum
 {
-	GtkTextBuffer *current_buffer;
-	PeasExtensionSet *extensions;
-	gchar *direct_save_uri;
-
-	GtkCssProvider *css_provider;
-	PangoFontDescription *font_desc;
+	SIGNAL_DROP_URIS,
+	N_SIGNALS
 };
 
+static guint signals[N_SIGNALS];
+
 G_DEFINE_TYPE_WITH_PRIVATE (GeditView, gedit_view, TEPL_TYPE_VIEW)
 
-enum
-{
-	DROP_URIS,
-	LAST_SIGNAL
-};
-
-static guint view_signals[LAST_SIGNAL] = { 0 };
-
 static void
-file_read_only_notify_handler (GtkSourceFile *file,
-			       GParamSpec    *pspec,
-			       GeditView     *view)
+update_editable (GeditView *view)
 {
-	gedit_debug (DEBUG_VIEW);
-
-	gtk_text_view_set_editable (GTK_TEXT_VIEW (view),
-				    !gtk_source_file_is_readonly (file));
-}
-
-static void
-current_buffer_removed (GeditView *view)
-{
-	if (view->priv->current_buffer != NULL)
-	{
-		GtkSourceFile *file;
-
-		file = gedit_document_get_file (GEDIT_DOCUMENT (view->priv->current_buffer));
-
-		g_signal_handlers_disconnect_by_func (file,
-						      file_read_only_notify_handler,
-						      view);
-
-		g_object_unref (view->priv->current_buffer);
-		view->priv->current_buffer = NULL;
-	}
-}
-
-static void
-on_notify_buffer_cb (GeditView  *view,
-		     GParamSpec *pspec,
-		     gpointer    userdata)
-{
-	GtkTextBuffer *buffer;
+	GeditDocument *doc;
 	GtkSourceFile *file;
 
-	current_buffer_removed (view);
-	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
-
-	if (!GEDIT_IS_DOCUMENT (buffer))
-	{
-		return;
-	}
-
-	file = gedit_document_get_file (GEDIT_DOCUMENT (buffer));
-
-	view->priv->current_buffer = g_object_ref (buffer);
-	g_signal_connect_object (file,
-				 "notify::read-only",
-				 G_CALLBACK (file_read_only_notify_handler),
-				 view,
-				 0);
+	doc = GEDIT_DOCUMENT (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
+	file = gedit_document_get_file (doc);
 
 	gtk_text_view_set_editable (GTK_TEXT_VIEW (view),
 				    !gtk_source_file_is_readonly (file));
 }
 
+static void
+file_read_only_notify_cb (GtkSourceFile *file,
+			  GParamSpec    *pspec,
+			  GeditView     *view)
+{
+	update_editable (view);
+}
+
+static void
+buffer_changed (GeditView *view)
+{
+	GeditDocument *doc;
+	GtkSourceFile *file;
+
+	doc = GEDIT_DOCUMENT (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
+	file = gedit_document_get_file (doc);
+
+	tepl_signal_group_clear (&view->priv->file_signal_group);
+	view->priv->file_signal_group = tepl_signal_group_new (G_OBJECT (file));
+
+	tepl_signal_group_add (view->priv->file_signal_group,
+			       g_signal_connect (file,
+						 "notify::read-only",
+						 G_CALLBACK (file_read_only_notify_cb),
+						 view));
+
+	update_editable (view);
+}
+
+static void
+buffer_notify_cb (GeditView  *view,
+		  GParamSpec *pspec,
+		  gpointer    user_data)
+{
+	buffer_changed (view);
+}
+
 static void
 gedit_view_init (GeditView *view)
 {
 	GtkTargetList *target_list;
-	GtkStyleContext *context;
+	GtkStyleContext *style_context;
 
 	gedit_debug (DEBUG_VIEW);
 
@@ -139,25 +125,23 @@ gedit_view_init (GeditView *view)
 		gtk_target_list_add_uri_targets (target_list, TARGET_URI_LIST);
 	}
 
+	/* GeditViewActivatable */
 	view->priv->extensions =
 		peas_extension_set_new (PEAS_ENGINE (gedit_plugins_engine_get_default ()),
 		                        GEDIT_TYPE_VIEW_ACTIVATABLE,
 		                        "view", view,
 		                        NULL);
 
-	/* Act on buffer change */
+	/* Act on buffer changes */
+	buffer_changed (view);
 	g_signal_connect (view,
 			  "notify::buffer",
-			  G_CALLBACK (on_notify_buffer_cb),
+			  G_CALLBACK (buffer_notify_cb),
 			  NULL);
 
-	view->priv->css_provider = gtk_css_provider_new ();
-	context = gtk_widget_get_style_context (GTK_WIDGET (view));
-	gtk_style_context_add_class (context, "gedit-view");
-
-	gtk_style_context_add_provider (context,
-					GTK_STYLE_PROVIDER (view->priv->css_provider),
-					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+	/* CSS stuff */
+	style_context = gtk_widget_get_style_context (GTK_WIDGET (view));
+	gtk_style_context_add_class (style_context, "gedit-view");
 }
 
 static void
@@ -166,8 +150,7 @@ gedit_view_dispose (GObject *object)
 	GeditView *view = GEDIT_VIEW (object);
 
 	g_clear_object (&view->priv->extensions);
-
-	current_buffer_removed (view);
+	tepl_signal_group_clear (&view->priv->file_signal_group);
 
 	/* Disconnect notify buffer because the destroy of the textview will set
 	 * the buffer to NULL, and we call get_buffer in the notify which would
@@ -175,41 +158,48 @@ gedit_view_dispose (GObject *object)
 	 * There is no problem calling g_signal_handlers_disconnect_by_func()
 	 * several times (if dispose() is called several times).
 	 */
-	g_signal_handlers_disconnect_by_func (view, on_notify_buffer_cb, NULL);
-
-	g_clear_object (&view->priv->css_provider);
-	g_clear_pointer (&view->priv->font_desc, pango_font_description_free);
+	g_signal_handlers_disconnect_by_func (view, buffer_notify_cb, NULL);
 
 	G_OBJECT_CLASS (gedit_view_parent_class)->dispose (object);
 }
 
+static void
+update_font (GeditView *view)
+{
+	GeditSettings *settings;
+	gchar *selected_font;
+
+	settings = _gedit_settings_get_singleton ();
+	selected_font = _gedit_settings_get_selected_font (settings);
+	tepl_utils_override_font (GTK_WIDGET (view), selected_font);
+	g_free (selected_font);
+}
+
+static void
+fonts_changed_cb (GeditSettings *settings,
+		  GeditView     *view)
+{
+	update_font (view);
+}
+
 static void
 gedit_view_constructed (GObject *object)
 {
 	GeditView *view = GEDIT_VIEW (object);
 	GeditSettings *settings;
 	GSettings *editor_settings;
-	gboolean use_default_font;
 
 	G_OBJECT_CLASS (gedit_view_parent_class)->constructed (object);
 
 	settings = _gedit_settings_get_singleton ();
 	editor_settings = _gedit_settings_peek_editor_settings (settings);
 
-	use_default_font = g_settings_get_boolean (editor_settings, GEDIT_SETTINGS_USE_DEFAULT_FONT);
-
-	if (use_default_font)
-	{
-		gedit_view_set_font (view, TRUE, NULL);
-	}
-	else
-	{
-		gchar *editor_font;
-
-		editor_font = g_settings_get_string (editor_settings, GEDIT_SETTINGS_EDITOR_FONT);
-		gedit_view_set_font (view, FALSE, editor_font);
-		g_free (editor_font);
-	}
+	update_font (view);
+	g_signal_connect_object (settings,
+				 "fonts-changed",
+				 G_CALLBACK (fonts_changed_cb),
+				 view,
+				 0);
 
 	g_settings_bind (editor_settings, GEDIT_SETTINGS_DISPLAY_LINE_NUMBERS,
 	                 view, "show-line-numbers",
@@ -307,7 +297,9 @@ gedit_view_drag_data_received (GtkWidget        *widget,
 			       guint             info,
 			       guint             timestamp)
 {
-	/* If this is an URL emit DROP_URIS, otherwise chain up the signal */
+	/* If this is an URL emit SIGNAL_DROP_URIS, otherwise chain up the
+	 * signal.
+	 */
 	switch (info)
 	{
 		case TARGET_URI_LIST:
@@ -318,7 +310,7 @@ gedit_view_drag_data_received (GtkWidget        *widget,
 
 			if (uri_list != NULL)
 			{
-				g_signal_emit (widget, view_signals[DROP_URIS], 0, uri_list);
+				g_signal_emit (widget, signals[SIGNAL_DROP_URIS], 0, uri_list);
 				g_strfreev (uri_list);
 
 				gtk_drag_finish (context, TRUE, FALSE, timestamp);
@@ -353,7 +345,7 @@ gedit_view_drag_data_received (GtkWidget        *widget,
 				uris = g_new (gchar *, 2);
 				uris[0] = view->priv->direct_save_uri;
 				uris[1] = NULL;
-				g_signal_emit (widget, view_signals[DROP_URIS], 0, uris);
+				g_signal_emit (widget, signals[SIGNAL_DROP_URIS], 0, uris);
 				g_free (uris);
 			}
 
@@ -424,56 +416,6 @@ gedit_view_drag_drop (GtkWidget      *widget,
 	return drop_zone;
 }
 
-static void
-show_line_numbers_menu (GeditView      *view,
-			GdkEventButton *event)
-{
-	GtkWidget *menu;
-	GtkWidget *item;
-	GeditSettings *settings;
-	GSettings *editor_settings;
-
-	menu = gtk_menu_new ();
-
-	item = gtk_check_menu_item_new_with_mnemonic (_("_Display line numbers"));
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item),
-					gtk_source_view_get_show_line_numbers (GTK_SOURCE_VIEW (view)));
-
-	settings = _gedit_settings_get_singleton ();
-	editor_settings = _gedit_settings_peek_editor_settings (settings);
-
-	g_settings_bind (editor_settings, GEDIT_SETTINGS_DISPLAY_LINE_NUMBERS,
-			 item, "active",
-			 G_SETTINGS_BIND_SET);
-
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-
-	g_signal_connect (menu,
-			  "selection-done",
-			  G_CALLBACK (gtk_widget_destroy),
-			  NULL);
-
-	gtk_widget_show_all (menu);
-	gtk_menu_popup_at_pointer (GTK_MENU (menu), (GdkEvent *)event);
-}
-
-static gboolean
-gedit_view_button_press_event (GtkWidget      *widget,
-			       GdkEventButton *event)
-{
-	if ((event->type == GDK_BUTTON_PRESS) &&
-	    (event->button == GDK_BUTTON_SECONDARY) &&
-	    (event->window == gtk_text_view_get_window (GTK_TEXT_VIEW (widget),
-						        GTK_TEXT_WINDOW_LEFT)))
-	{
-		show_line_numbers_menu (GEDIT_VIEW (widget), event);
-
-		return GDK_EVENT_STOP;
-	}
-
-	return GTK_WIDGET_CLASS (gedit_view_parent_class)->button_press_event (widget, event);
-}
-
 static void
 extension_added (PeasExtensionSet *extensions,
 		 PeasPluginInfo   *info,
@@ -642,19 +584,19 @@ gedit_view_delete_from_cursor (GtkTextView   *text_view,
 			       GtkDeleteType  type,
 			       gint           count)
 {
-	/* We override the standard handler for delete_from_cursor since
-	 * the GTK_DELETE_PARAGRAPHS case is not implemented as we like (i.e. it
-	 * does not remove the carriage return in the previous line).
+	/* We override the standard handler for delete_from_cursor since the
+	 * GTK_DELETE_PARAGRAPHS case is not implemented as we like (i.e. it
+	 * does not remove the newline in the previous line).
 	 */
-	switch (type)
+	if (type == GTK_DELETE_PARAGRAPHS)
 	{
-		case GTK_DELETE_PARAGRAPHS:
-			delete_line (text_view, count);
-			break;
+		delete_line (text_view, count);
+		return;
+	}
 
-		default:
-			GTK_TEXT_VIEW_CLASS (gedit_view_parent_class)->delete_from_cursor(text_view, type, count);
-			break;
+	if (GTK_TEXT_VIEW_CLASS (gedit_view_parent_class)->delete_from_cursor != NULL)
+	{
+		GTK_TEXT_VIEW_CLASS (gedit_view_parent_class)->delete_from_cursor (text_view, type, count);
 	}
 }
 
@@ -691,7 +633,6 @@ gedit_view_class_init (GeditViewClass *klass)
 	widget_class->drag_data_received = gedit_view_drag_data_received;
 	widget_class->drag_drop = gedit_view_drag_drop;
 
-	widget_class->button_press_event = gedit_view_button_press_event;
 	widget_class->realize = gedit_view_realize;
 	widget_class->unrealize = gedit_view_unrealize;
 
@@ -715,7 +656,7 @@ gedit_view_class_init (GeditViewClass *klass)
 	 * should NOT use this signal because this will not prevent gedit from
 	 * loading the URI.
 	 */
-	view_signals[DROP_URIS] =
+	signals[SIGNAL_DROP_URIS] =
 		g_signal_new ("drop-uris",
 		              G_TYPE_FROM_CLASS (object_class),
 		              G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
@@ -723,31 +664,40 @@ gedit_view_class_init (GeditViewClass *klass)
 		              NULL, NULL, NULL,
 		              G_TYPE_NONE, 1, G_TYPE_STRV);
 
+	/* FIXME: some of these bindings - especially for the "change-case" -
+	 * could be moved to a plugin that enables more advanced keyboard
+	 * shortcuts. Enabling too many keyboard shortcuts by default makes the
+	 * user experience worse, because when mistyping a key it could trigger
+	 * an unknown/unexpected action, so it's a bit a WTF moment for the
+	 * user. gedit must not become like Emacs or Vim. More advanced stuff
+	 * are put in plugins. Also, the "change-case" is available in the
+	 * right-click menu, so it's already easily accessible.
+	 */
 	binding_set = gtk_binding_set_by_class (klass);
 
 	gtk_binding_entry_add_signal (binding_set,
 	                              GDK_KEY_d,
 	                              GDK_CONTROL_MASK,
-	                              "delete_from_cursor", 2,
+	                              "delete-from-cursor", 2,
 	                              G_TYPE_ENUM, GTK_DELETE_PARAGRAPHS,
 	                              G_TYPE_INT, 1);
 
 	gtk_binding_entry_add_signal (binding_set,
 	                              GDK_KEY_u,
 	                              GDK_CONTROL_MASK,
-	                              "change_case", 1,
+	                              "change-case", 1,
 	                              G_TYPE_ENUM, GTK_SOURCE_CHANGE_CASE_UPPER);
 
 	gtk_binding_entry_add_signal (binding_set,
 	                              GDK_KEY_l,
 	                              GDK_CONTROL_MASK,
-	                              "change_case", 1,
+	                              "change-case", 1,
 	                              G_TYPE_ENUM, GTK_SOURCE_CHANGE_CASE_LOWER);
 
 	gtk_binding_entry_add_signal (binding_set,
 	                              GDK_KEY_asciitilde,
 	                              GDK_CONTROL_MASK,
-	                              "change_case", 1,
+	                              "change-case", 1,
 	                              G_TYPE_ENUM, GTK_SOURCE_CHANGE_CASE_TOGGLE);
 }
 
@@ -770,149 +720,4 @@ gedit_view_new (GeditDocument *doc)
 			     NULL);
 }
 
-/**
- * gedit_view_cut_clipboard:
- * @view: a #GeditView.
- *
- * Deprecated: 3.38: Use tepl_view_cut_clipboard() instead.
- */
-void
-gedit_view_cut_clipboard (GeditView *view)
-{
-	g_return_if_fail (GEDIT_IS_VIEW (view));
-	tepl_view_cut_clipboard (TEPL_VIEW (view));
-}
-
-/**
- * gedit_view_copy_clipboard:
- * @view: a #GeditView.
- *
- * Deprecated: 3.38: Use tepl_view_copy_clipboard() instead.
- */
-void
-gedit_view_copy_clipboard (GeditView *view)
-{
-	g_return_if_fail (GEDIT_IS_VIEW (view));
-	tepl_view_copy_clipboard (TEPL_VIEW (view));
-}
-
-/**
- * gedit_view_paste_clipboard:
- * @view: a #GeditView.
- *
- * Deprecated: 3.38: Use tepl_view_paste_clipboard() instead.
- */
-void
-gedit_view_paste_clipboard (GeditView *view)
-{
-	g_return_if_fail (GEDIT_IS_VIEW (view));
-	tepl_view_paste_clipboard (TEPL_VIEW (view));
-}
-
-/**
- * gedit_view_delete_selection:
- * @view: a #GeditView
- *
- * Deletes the text currently selected in the #GtkTextBuffer associated
- * to the view and scroll to the cursor position.
- *
- * Deprecated: 3.38: use tepl_view_delete_selection() instead.
- */
-void
-gedit_view_delete_selection (GeditView *view)
-{
-	g_return_if_fail (GEDIT_IS_VIEW (view));
-	tepl_view_delete_selection (TEPL_VIEW (view));
-}
-
-/**
- * gedit_view_select_all:
- * @view: a #GeditView
- *
- * Selects all the text.
- *
- * Deprecated: 3.38: use tepl_view_select_all() instead.
- */
-void
-gedit_view_select_all (GeditView *view)
-{
-	g_return_if_fail (GEDIT_IS_VIEW (view));
-	tepl_view_select_all (TEPL_VIEW (view));
-}
-
-/**
- * gedit_view_scroll_to_cursor:
- * @view: a #GeditView
- *
- * Scrolls the @view to the cursor position.
- *
- * Deprecated: 3.38: Use tepl_view_scroll_to_cursor() instead.
- */
-void
-gedit_view_scroll_to_cursor (GeditView *view)
-{
-	g_return_if_fail (GEDIT_IS_VIEW (view));
-	tepl_view_scroll_to_cursor (TEPL_VIEW (view));
-}
-
-static void
-update_css_provider (GeditView *view)
-{
-	gchar *str;
-	gchar *css;
-
-	g_assert (GEDIT_IS_VIEW (view));
-	g_assert (view->priv->font_desc != NULL);
-
-	str = gedit_pango_font_description_to_css (view->priv->font_desc);
-	css = g_strdup_printf ("textview { %s }", str ? str : "");
-	gtk_css_provider_load_from_data (view->priv->css_provider, css, -1, NULL);
-
-	g_free (css);
-	g_free (str);
-}
-
-/**
- * gedit_view_set_font:
- * @view: a #GeditView
- * @default_font: whether to reset to the default font
- * @font_name: the name of the font to use
- *
- * If @default_font is #TRUE, resets the font of the @view to the default font.
- * Otherwise sets it to @font_name.
- */
-void
-gedit_view_set_font (GeditView   *view,
-		     gboolean     default_font,
-		     const gchar *font_name)
-{
-	gedit_debug (DEBUG_VIEW);
-
-	g_return_if_fail (GEDIT_IS_VIEW (view));
-
-	g_clear_pointer (&view->priv->font_desc, pango_font_description_free);
-
-	if (default_font)
-	{
-		GeditSettings *settings;
-		gchar *font;
-
-		settings = _gedit_settings_get_singleton ();
-		font = gedit_settings_get_system_font (settings);
-
-		view->priv->font_desc = pango_font_description_from_string (font);
-		g_free (font);
-	}
-	else
-	{
-		g_return_if_fail (font_name != NULL);
-
-		view->priv->font_desc = pango_font_description_from_string (font_name);
-	}
-
-	g_return_if_fail (view->priv->font_desc != NULL);
-
-	update_css_provider (view);
-}
-
 /* ex:set ts=8 noet: */
