@@ -21,6 +21,13 @@ from .library import ToolLibrary
 from .manager import Manager
 import os
 
+try:
+    import gettext
+    gettext.bindtextdomain('gedit')
+    gettext.textdomain('gedit')
+    _ = gettext.gettext
+except:
+    _ = lambda s: s
 
 class ToolMenu(object):
     def __init__(self, library, menu):
@@ -53,7 +60,7 @@ class ToolMenu(object):
 
         for tool in sorted(directory.tools, key=lambda x: x.name.lower()):
             # FIXME: find a better way to share the action name
-            action_name = 'external-tool_%X_%X' % (id(tool), id(tool.name))
+            action_name = 'external-tool-%X-%X' % (id(tool), id(tool.name))
             item = Gio.MenuItem.new(tool.name.replace('_', '__'), "win.%s" % action_name)
             item.set_attribute_value("hidden-when", GLib.Variant.new_string("action-disabled"))
             menu.append_item(item)
@@ -123,7 +130,7 @@ class AppActivatable(GObject.Object, Gedit.AppActivatable):
                                                  self.css, 600)
 
         self.menu_ext = self.extend_menu("preferences-section")
-        item = Gio.MenuItem.new(_("Manage _External Tools..."), "app.manage-tools")
+        item = Gio.MenuItem.new(_("Manage _External Tools…"), "app.manage-tools")
         self.menu_ext.append_menu_item(item)
 
         self.submenu_ext = self.extend_menu("tools-section-1")
